@@ -16,7 +16,7 @@
 //!   code: u8,
 //!   checksum: u16,
 //!   rest_of_header: [u8; 4],
-//!   data_section: [u8], // open ended byte array, matches until the end of the package
+//!   data_section: [u8], // open ended byte array, matches until the end of the packet
 //! });
 //!
 //! fn func(packet_data: &mut [u8]) {
@@ -28,7 +28,7 @@
 //!
 //!   // write some data
 //!   view.checksum_mut().write(10);
-//!   // equivalent: packet_data[2..4].copy_from_slice(&10u16.to_le_bytes());
+//!   // equivalent: packet_data[2..4].copy_from_slice(&10u16.to_be_bytes());
 //!
 //!   // access an open ended byte array
 //!   let data_section: &[u8] = view.data_section().data();
@@ -40,13 +40,15 @@
 //! }
 //! ```
 //!
+//! See the [icmp_packet](crate::example::icmp_packet) module for what this [define_layout!] macro generates for you.
+//!
 //! # What to use this library for?
 //! Anything that needs inplace zero-copy access to structured binary data.
 //! - Network packets are an obvious example
 //! - File system inodes
 //! - Structured binary data in files if you want to avoid explicit (de)serialization, possibly in combination with [memmap](https://docs.rs/memmap).
 //!
-//! # Why use this library?
+//! ## Why use this library?
 //! - Inplace, zero-copy, type-safe access to your data.
 //! - Data layout is defined in one central place, call sites can't accidentally use wrong field offsets.
 //! - Convenient and simple macro DSL to define layouts.
@@ -55,40 +57,41 @@
 //! - Const generics make sure that all offset calculations happen at compile time and will not have a runtime overhead.
 //! - Comprehensive test coverage.
 //!
-//! # Why not `#[repr(packed)]`?
+//! ## Why not `#[repr(packed)]`?
 //! Annotating structs with `#[repr(packed)]` gives some of the features of this crate, namely it lays out the data fields exactly in the order they're specified
 //! without padding. But it has serious shortcomings that this library solves.
 //! - `#[repr(packed)]` uses the system byte order, which will be different depending on if you're running on a little endian or big endian system. `#[repr(packed)]` is not cross-platform compatible. This library is.
 //! - `#[repr(packed)]` [can cause undefined behavior on some CPUs when taking references to unaligned data](https://doc.rust-lang.org/nomicon/other-reprs.html#reprpacked).
 //!    This library avoids that by not offering any API that takes references to unaligned data. The only data type you can get a reference to is byte arrays, and they only require an alignment of 1 which is trivially always fulfilled.
 //!
-//! # When not to use this library?
-//! - You need dynamic data structures, e.g. a list that can change size. This library only supports static data layouts.
-//! - Not all of your data fits into the memory and you need to process streams of data.
+//! ## When not to use this library?
+//! - You need dynamic data structures, e.g. a list that can change size. This library only supports static data layouts (with the exception of open ended byte arrays at the end of a layout).
+//! - Not all of your layout fits into the memory and you need to process streams of data.
+//!   Note that this crate can still be helpful if you have smaller layouted packages as part of a larger stream, as long as any one layouted packet fits into memory.
 //!
-//! # Alternatives
+//! ## Alternatives
 //! To the best of my knowledge, there is no other library offering inplace, zero-copy and type-safe access to structured binary data.
 //! But if you don't need direct access to your data and are ok with a serialization/deserialization step, then there is a number of amazing libraries out there.
 //! - [Nom](https://crates.io/crates/nom) is a great crate for all your parsing needs. It can for example parse binary data and put them in your custom structs.
 //! - [Binread](https://crates.io/crates/binread), [Binwrite](https://crates.io/crates/binwrite), [Binrw](https://crates.io/crates/binrw) are great libraries for (de)serializing binary data.
 //!
-//! //! # APIs
-//! This library offers two alternative APIs:
+//! # APIs
+//! Layouts are defined using the [define_layout!] macro. Based on such a layout, this library offers two alternative APIs for data access:
 //! 1. The [Field] API that offers free functions to read/write the data based on an underlying slice of storage (`packet_data` in the example above) holding the packet data. This API does not wrap the underlying slice of storage data, which means you have to pass it in to each accessor.
 //!    This is not the API used in the example above, see [Field] for an API example.
 //! 2. The [FieldView] API that wraps a slice of storage data and remembers it in a `View` object, allowing access to the fields without having to pass in the packed data slice each time. This is the API used in the example above. See [FieldView] for another example.
 //!
-//! # Supported field types
-//! ## Primitive integer types
+//! ## Supported field types
+//! ### Primitive integer types
 //! - [u8](https://doc.rust-lang.org/stable/std/primitive.u8.html), [u16](https://doc.rust-lang.org/stable/std/primitive.u16.html), [u32](https://doc.rust-lang.org/stable/std/primitive.u32.html), [u64](https://doc.rust-lang.org/stable/std/primitive.u64.html)
 //! - [i8](https://doc.rust-lang.org/stable/std/primitive.i8.html), [i16](https://doc.rust-lang.org/stable/std/primitive.i16.html), [i32](https://doc.rust-lang.org/stable/std/primitive.i32.html), [i64](https://doc.rust-lang.org/stable/std/primitive.i64.html)
 //!
 //! For these fields, the [Field] API offers [Field::read], [Field::write] and the [FieldView] API offers [FieldView::read] and [FieldView::write].
 //!
-//! ## Fixed size byte arrays: `[u8; N]`.
+//! ### Fixed size byte arrays: `[u8; N]`.
 //! For these fields, the [Field] API offers [Field::data], [Field::data_mut], and the [FieldView] API offers [FieldView::data] and [FieldView::data_mut].
 //!
-//! ## Open ended byte arrays: `[u8]`.
+//! ### Open ended byte arrays: `[u8]`.
 //! This field type can only occur as the last field of a layout and will mach the remaining data until the end of the storage.
 //! This field has a dynamic size, depending on how large the package data is.
 //! For these fields, the [Field] API offers [Field::data], [Field::data_mut](Field::data_mut) and the [FieldView] API offers [FieldView::data], [FieldView::data_mut] and [FieldView::extract].
@@ -98,7 +101,7 @@
 //! - [bool](https://doc.rust-lang.org/stable/std/primitive.bool.html) stored as 1 byte
 //! - [bool](https://doc.rust-lang.org/stable/std/primitive.bool.html) stored as 1 bit
 //!
-//! ## Data types with dynamic length
+//! ### Data types with dynamic length
 //! This crate relies on a static layout, it cannot support data types with dynamic length.
 //! In theory, types with dynamic length could be supported if they either
 //! - are the last field of a layout, an already implemented example of this are open ended byte arrays.
@@ -107,17 +110,19 @@
 //!
 //! Both of these, however, would be some effort to implement and it is unclear if that will ever happen (unless somebody opens a PR for it).
 //!
-//! ## Strings
+//! ### Strings
 //! For strings, note that even fixed-size UTF-8 strings take a variable number of characters because of the UTF-8 encoding and that brings all the issues of data types with dynamic length with it.
 //! This is why strings aren't supported yet.
 //!
-//! ## Fixed-size arrays other than `[u8; N]`
+//! ### Fixed-size arrays other than `[u8; N]`
 //! Say we wanted to have a `[u32; N]` field. The API couldn't just return a zero-copy `&[u32; N]` to the caller because that would use the system byte order (i.e. endianness) which might be different from the byte order defined in the package layout.
 //! To make this cross-platform compatible, we'd have to wrap these slices into our own slice type that enforces the correct byte order and return that from the API.
 //! This complexity is why it wasn't implemented yet, but feel free to open a PR if you need this.
 
 #![forbid(unsafe_code)]
+// TODO #![deny(missing_docs)]
 
+pub mod example;
 mod fields;
 mod macro_define_layout;
 
@@ -125,6 +130,12 @@ pub use fields::{
     BigEndian, Field, FieldMetadata, FieldSize, FieldView, LittleEndian, SizedFieldMetadata,
 };
 
+/// Import this to get everything into scope that you need for defining and using layouts.
+///
+/// # Example
+/// ```
+/// use binary_layout::prelude::*;
+/// ```
 pub mod prelude {
     pub use super::{FieldMetadata, SizedFieldMetadata};
     pub use crate::define_layout;
